==> lxqt-config_1.1.0.orig.tar.xz: lxqt-config-1.1.0/lxqt-config-appearance/translations/lxqt-config-appearance_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Värvi muutmiseks klõpsi.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Vali värv</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK teemad</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;„%1“ andmed on nüüd asendatud.&lt;/p&gt;&lt;p&gt;Koopia oma vanadest seadistustest leiad siit - „%2“&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Viga: gsettings käivitamine ei õnnestu</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fondid</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Kasutajaliidese vaikimisi font</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Fondi nimi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stiil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Fondi suurus:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Tavaline</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Paks</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kaldkiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Paks kaldkiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Tehtud muudatused mõjuvad vaid avatavatele rakendustele</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Kasuta silutud fonte</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Fontide varjundamise stiil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Puudub</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Napp</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Keskmine</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Täielik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Fontide varjundamine</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Eralduvõime (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Varjunda automaatselt</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Alampikslite silumine:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK välimus</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Vali GTK teemad (sellega muudame ka GTK seadistuste failid!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 teema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 teema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Selleks, et teemad oleks ühtlased, siis kui vähegi võimalik, palun vali samad stiilid/teemad kõikides loendites. Alternatiivina vali GTK teemade jäljendamiseks Qt teemaks „gtk2“.

Kui soovid GTK-põhiste rakenduste välimust lennult muuta, siis palun kontrolli et „xsettingsd“ oleks paigaldatud.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt välimuse seadistamine</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Ikooniteema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG ikooniteemade KDE laiendus -&gt; Järgi värviteemat</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Värvi ikoonid vidinate stiili ja värvipaleti alusel</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt teema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Asenda kasutaja määratud taustapilt</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Värvipaletid</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Eemalda</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt välimuse seadistused</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>Vidina stiil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>Ikooniteema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt teema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation>GTK välimus</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Vidina stiil</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Mõned Qt stiilid võivad need värvid jätta kasutamata.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Aken:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Vaade:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Valik:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Akna tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Vaate tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Valitud tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Külastatud link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Salvesta värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;Laadi värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>Taasta värvipaleti &amp;vaikeväärtus</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>Tööriistariba nuppude stiil:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>Ainult ikoon</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>Ainult tekst</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>Tekst ikooni kõrval</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>Tekst ikooni all</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>Vaikimisi väärtus</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>Käivita objektid ühe klõpsuga</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt stiil</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>Salvesta värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>Värvipaleti nimi:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Sellise nimega värvipalett on juba olemas.
Kas sa soovid ta asendada?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>Kustuta värvipaletid</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Kas sa kindlasti soovid kustutada valitud värvipaleti(d)?
Kui algsed paletis on olemas, siis need ei muutu.</translation>
    </message>
</context>
</TS>

==> lxqt-config_1.4.0.orig.tar.xz: lxqt-config-1.4.0/lxqt-config-appearance/translations/lxqt-config-appearance_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Värvi muutmiseks klõpsi.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Vali värv</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK teemad</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;„%1“ andmed on nüüd asendatud.&lt;/p&gt;&lt;p&gt;Koopia oma vanadest seadistustest leiad siit - „%2“&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Viga: gsettings käivitamine ei õnnestu</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fondid</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Kasutajaliidese vaikimisi font</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Fondi nimi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stiil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Fondi suurus:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Tavaline</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Paks</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kaldkiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Paks kaldkiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Tehtud muudatused mõjuvad vaid avatavatele rakendustele</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Kasuta silutud fonte</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Fontide varjundamise stiil:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Puudub</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Napp</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Keskmine</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Täielik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Fontide varjundamine</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Eralduvõime (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Varjunda automaatselt</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Alampikslite silumine:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK välimus</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Vali GTK teemad (sellega muudame ka GTK seadistuste failid!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 teema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 teema</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Selleks, et teemad oleks ühtlased, siis kui vähegi võimalik, palun vali samad stiilid/teemad kõikides loendites. Alternatiivina vali GTK teemade jäljendamiseks Qt teemaks „gtk2“.

Kui soovid GTK-põhiste rakenduste välimust lennult muuta, siis palun kontrolli et „xsettingsd“ oleks paigaldatud.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt välimuse seadistamine</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Ikooniteema</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG ikooniteemade KDE laiendus -&gt; Järgi värviteemat</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Värvi ikoonid vidinate stiili ja värvipaleti alusel</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt teema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Kasuta teemaga määratud taustapilti</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="94"/>
        <source>(User Theme)</source>
        <translation>(Kasutaja üldine teema)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="182"/>
        <source>Open theme folder</source>
        <translation>Ava teemade kaust</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Värvipaletid</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Otsi...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Eemalda</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt välimuse seadistused</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>Vidina stiil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>Ikooniteema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt teema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation>GTK välimus</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Vidina stiil</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Mõned Qt stiilid võivad need värvid jätta kasutamata.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Aken:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Vaade:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Valik:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Akna tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Vaate tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Valitud tekst:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Külastatud link:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Salvesta värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;Laadi värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>Taasta värvipaleti &amp;vaikeväärtus</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>Tööriistariba nuppude stiil:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>Ainult ikoon</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>Ainult tekst</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>Tekst ikooni kõrval</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>Tekst ikooni all</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>Vaikimisi väärtus</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>Käivita objektid ühe klõpsuga</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt stiil</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>Salvesta värvipalett</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>Värvipaleti nimi:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Sellise nimega värvipalett on juba olemas.
Kas sa soovid ta asendada?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>Kustuta värvipaletid</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Kas sa kindlasti soovid kustutada valitud värvipaleti(d)?
Kui algsed paletis on olemas, siis need ei muutu.</translation>
    </message>
</context>
</TS>
